Properties Methods Events Config Options Direct Link

# Class Ext.ensible.cal.EventContextMenu

Package: | Ext.ensible.cal
Defined In: | EventContextMenu.js
Class: | EventContextMenu
Extends: | Object

The context menu displayed for calendar events in any CalendarView subclass.

## Config Options

Config Options | Defined By
--- | ---
| deleteText : String The text to display for the 'Delete' option in the menu. | EventContextMenu
| editDetailsText : String The text to display for the 'Edit Details' option in the menu. | EventContextMenu
| hideOnClick : Boolean False to continue showing the menu after a color is selected, defaults to true. | EventContextMenu
| ignoreParentClicks : Boolean True to ignore clicks on any item in this menu that is a parent item (displays a submenu) so that the submenu is not... True to ignore clicks on any item in this menu that is a parent item (displays a submenu) so that the submenu is not dismissed when clicking the parent item (defaults to true). | EventContextMenu
| moveToText : String The text to display for the 'Move to...' option in the menu. | EventContextMenu

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| buildMenu() : void Overrideable method intended for customizing the menu items. This should only to be used for overriding or called fr... Overrideable method intended for customizing the menu items. This should only to be used for overriding or called from a subclass and should not be called directly from application code. Parameters: None. Returns: void | EventContextMenu
| showForEvent( `Ext.ensible.cal.EventRecord rec`, `Ext.Element el`, `Array xy` ) : void Shows the specified event at the given XY position. Shows the specified event at the given XY position. Parameters: `rec` : Ext.ensible.cal.EventRecord The record for the event `el` : Ext.Element The element associated with this context menu `xy` : Array The X & Y [x, y] values for the position at which to show the menu (coordinates are page-based) Returns: void | EventContextMenu

## Public Events

Event | Defined By
--- | ---
| editdetails : ( `Ext.ensible.cal.EventContextMenu this`, `Ext.ensible.cal.EventRecord rec`, `Ext.Element el` ) Fires when the user selects the option to edit the event details (by default, in an instance of Ext.ensible.cal.Event... Fires when the user selects the option to edit the event details (by default, in an instance of Ext.ensible.cal.EventEditForm. Handling code should transfer the current event record to the appropriate instance of the detailed form by showing the form and calling loadRecord. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.EventContextMenu `rec` : Ext.ensible.cal.EventRecord The record that is currently being edited `el` : Ext.Element The element associated with this context menu | EventContextMenu
| eventdelete : ( `Ext.ensible.cal.EventContextMenu this`, `Ext.ensible.cal.EventRecord rec`, `Ext.Element el` ) Fires after the user selectes the option to delete an event. Note that this menu does not actually delete the event f... Fires after the user selectes the option to delete an event. Note that this menu does not actually delete the event from the data store. This is simply a notification that the menu option was selected -- it is the responsibility of handling code to perform the deletion and any clean up required. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.EventContextMenu `rec` : Ext.ensible.cal.EventRecord The record for the event to be deleted `el` : Ext.Element The element associated with this context menu | EventContextMenu
| eventmove : ( `Ext.ensible.cal.EventContextMenu this`, `Ext.ensible.cal.EventRecord rec`, `Date dt` ) Fires after the user selects a date in the calendar picker under the "move event" menu option. Note that this menu do... Fires after the user selects a date in the calendar picker under the "move event" menu option. Note that this menu does not actually update the event in the data store. This is simply a notification that the menu option was selected -- it is the responsibility of handling code to perform the move action and any clean up required. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.EventContextMenu `rec` : Ext.ensible.cal.EventRecord The record for the event to be moved `dt` : Date The new start date for the event (the existing event start time will be preserved) | EventContextMenu